@@ -24,7 +24,7 @@ try:
 except ImportError:
     pytils_enabled = False
 
-from pybb.models import TopicReadTracker, ForumReadTracker
+from pybb.models import TopicReadTracker, ForumReadTracker, PollAnswerUser
 from pybb import defaults
 
 
@@ -185,4 +185,8 @@ def pybb_topic_inline_pagination(topic):
     page_count = int(math.ceil(topic.post_count / float(defaults.PYBB_TOPIC_PAGE_SIZE)))
     if page_count <= 5:
         return range(1, page_count+1)
-    return range(1, 5) + ['...', page_count]
\ No newline at end of file
+    return range(1, 5) + ['...', page_count]
+
+@register.filter
+def pybb_topic_poll_not_voted(topic, user):
+    return not PollAnswerUser.objects.filter(poll_answer__topic=topic, user=user).exists()
\ No newline at end of file
