@@ -6,6 +6,7 @@ import os
 from django.contrib.auth.models import User, Permission
 from django.core import mail
 from django.core.urlresolvers import reverse
+from django.core.exceptions import ValidationError
 from django.test import TransactionTestCase
 from django.test.client import Client
 
@@ -145,7 +146,6 @@ class FeaturesTest(TransactionTestCase, SharedTestModule):
         topic.delete()
         Forum.objects.get(id=self.forum.id)
 
-
     def test_forum_updated(self):
         time.sleep(1)
         topic = Topic(name='xtopic', forum=self.forum, user=self.user)
@@ -330,8 +330,6 @@ class FeaturesTest(TransactionTestCase, SharedTestModule):
         self.assertEqual(ForumReadTracker.objects.filter(user=self.user).count(), 1)
         self.assertEqual(ForumReadTracker.objects.filter(user=self.user, forum=self.forum).count(), 1)
 
-
-
     def test_hidden(self):
         client = Client()
         category = Category(name='hcat', hidden=True)
@@ -559,7 +557,6 @@ class FeaturesTest(TransactionTestCase, SharedTestModule):
         defaults.PYBB_PREMODERATION = self.ORIG_PYBB_PREMODERATION
 
 
-
 class AnonymousTest(TransactionTestCase, SharedTestModule):
 
     def setUp(self):
@@ -729,10 +726,23 @@ class AttachmentTest(TransactionTestCase, SharedTestModule):
         self.assertEqual(response.status_code, 200)
         self.assertTrue(Post.objects.filter(body='test attachment').exists())
 
+    def test_attachment(self):
+        add_post_url = reverse('pybb:add_post', kwargs={'topic_id': self.topic.id})
+        self.login_client()
+        response = self.client.get(add_post_url)
+        values = self.get_form_values(response)
+        values['body'] = 'test attachment'
+        values['attachments-0-file'] = self.file
+        del values['attachments-INITIAL_FORMS']
+        del values['attachments-TOTAL_FORMS']
+        with self.assertRaises(ValidationError):
+            self.client.post(add_post_url, values, follow=True)
+
     def tearDown(self):
         defaults.PYBB_ATTACHMENT_ENABLE = self.PYBB_ATTACHMENT_ENABLE
         defaults.PYBB_PREMODERATION = self.ORIG_PYBB_PREMODERATION
 
+
 class PollTest(TransactionTestCase, SharedTestModule):
     def setUp(self):
         self.create_user()
@@ -786,6 +796,32 @@ class PollTest(TransactionTestCase, SharedTestModule):
         self.assertEqual(new_topic.poll_question, 'q1')
         self.assertEqual(PollAnswer.objects.filter(topic=new_topic).count(), 2)
 
+    def test_regression_poll_deletion_after_second_post(self):
+        self.login_client()
+
+        add_topic_url = reverse('pybb:add_topic', kwargs={'forum_id': self.forum.id})
+        response = self.client.get(add_topic_url)
+        values = self.get_form_values(response)
+        values['body'] = 'test poll body'
+        values['name'] = 'test poll name'
+        values['poll_type'] = 1 # poll type = single choice, create answers
+        values['poll_question'] = 'q1'
+        values['poll_answers-0-text'] = 'answer1' # two answers - what do we need to create poll
+        values['poll_answers-1-text'] = 'answer2'
+        values['poll_answers-TOTAL_FORMS'] = 2
+        response = self.client.post(add_topic_url, values, follow=True)
+        self.assertEqual(response.status_code, 200)
+        new_topic = Topic.objects.get(name='test poll name')
+        self.assertEqual(new_topic.poll_question, 'q1')
+        self.assertEqual(PollAnswer.objects.filter(topic=new_topic).count(), 2)
+
+        add_post_url = reverse('pybb:add_post', kwargs={'topic_id': new_topic.id})
+        response = self.client.get(add_post_url)
+        values = self.get_form_values(response)
+        values['body'] = 'test answer body'
+        response = self.client.post(add_post_url, values, follow=True)
+        self.assertEqual(PollAnswer.objects.filter(topic=new_topic).count(), 2)
+
     def test_poll_edit(self):
         edit_topic_url = reverse('pybb:edit_post', kwargs={'pk': self.post.id})
         self.login_client()
